from formats import message_metadata
from formats.mission_plan import full_mission_plan_schema
from formats.observation import full_observation_schema
from formats.planning_configuration import full_planning_configuration_schema
from formats.platform_status import full_platform_status_message_schema
from formats.acknowledgement import full_acknowledgement_schema

from flasgger import Swagger
from flask import Flask

app = Flask(__name__)

swagger_config = {
    "headers": [],
    "openapi": "3.0.2",
    "swagger_ui": True,
    "specs_route": "/",
    "info": {
        "title": "Backbone Message Formats",
        "version": "0.1",
        "description": "SoAR message schemas (i.e. formats)",
    },
    "specs": [
        {
            "endpoint": "swagger",
            "route": "/swagger.json",
            "rule_filter": lambda rule: True,
            "model_filter": lambda tag: True,
        }
    ],
    "components": {
        "schemas": {
            "Metadata": message_metadata,
            "MissionPlan": full_mission_plan_schema,
            "Observation": full_observation_schema,
            "PlanningConfiguration": full_planning_configuration_schema,
            "PlatformStatus": full_platform_status_message_schema,
            "Acknowledgement": full_acknowledgement_schema,
        }
    },
    "paths": {
        "/all_messages": {
            "get": {
                "description": "Returns all messages from the system.",
                "responses": {
                    "200": {
                        "description": "A list of messages.",
                        "content": {
                            "application/json": {
                                "schema": {
                                    "oneOf": [
                                        {
                                            "$ref": "#/components/schemas/"
                                            + "Acknowledgement"
                                        },
                                        {
                                            "$ref": "#/components/schemas/"
                                            + "MissionPlan"
                                        },
                                        {
                                            "$ref": "#/components/schemas/"
                                            + "Observation"
                                        },
                                        {
                                            "$ref": "#/components/schemas/"
                                            + "PlanningConfiguration"
                                        },
                                        {
                                            "$ref": "#/components/schemas/"
                                            + "PlatformStatus"
                                        },
                                    ],
                                    "discriminator": {
                                        "propertyName": "message_type",
                                    },
                                }
                            }
                        },
                    }
                },
            }
        },
    },
    "produces": ["application/json"],
    "consumes": ["application/json"],
}
message_types = [
    "Metadata",
    # "Acknowledgement",
    "MissionPlan",
    "Observation",
    "PlanningConfiguration",
    "PlatformStatus",
]
for item in message_types:
    swagger_config["paths"]["/" + str(item.lower())] = {
        "get": {
            "description": "Returns message for " + item,
            "responses": {
                "200": {
                    "description": item + " message.",
                    "content": {
                        "application/json": {
                            "schema": {
                                "allOf": [
                                    {
                                        "$ref": "#/components/schemas/" + item,
                                    },
                                ],
                                "discriminator": {
                                    "propertyName": "message_type",
                                },
                            }
                        }
                    },
                }
            },
        }
    }

swag = Swagger(app, config=swagger_config, merge=True)


if __name__ == "__main__":
    app.run(debug=True)
    # print(validate_spec_url("http://127.0.0.1:5000/swagger.json"))

    # # If no exception is raised by validate_spec(), the spec is valid.
    # validate_spec(swagger_config)
    # print("000 Schema validation passed")

    # errors_iterator = openapi_v3_spec_validator.iter_errors(swagger_config)
    # print(errors_iterator)
